# 주요용어

## Servo On

- **Servo**: Servomechanism의 준말로, 특정 위치로 이동하거나 특정 힘을 유지하는 등의 작업을 수행하는 장치를 의미함. 로봇의 모터를 제어하는 장치를 의미하기도 함.
- **Servo On**: 로봇의 모터를 활성화하는 명령어. 로봇을 조작하기 위해서는 반드시 Servo On 명령어를 실행해야 함.
